@@ -21,7 +21,8 @@ class GetQueueAttributesCommand(BaseRSMQCommand):
 
     def exec_command(self):
         ''' Exec Command '''
-        now = int(time.time())
+        secs, usecs = self.client.time()
+        now = secs * 1000 + int(usecs / 1000)
 
         queue_base = self.queue_base
         queue_key = self.queue_key
@@ -30,7 +31,7 @@ class GetQueueAttributesCommand(BaseRSMQCommand):
         tx.hmget(queue_key, "vt", "delay", "maxsize", "totalrecv", "totalsent", "created",
                  "modified")
         tx.zcard(queue_base)
-        tx.zcount(queue_base, "%s000" % now, "+inf")
+        tx.zcount(queue_base, now, "+inf")
 
         results = tx.execute()
 
@@ -40,13 +41,13 @@ class GetQueueAttributesCommand(BaseRSMQCommand):
         stats = results[0]
 
         return {
-            "vt": stats[0],
-            "delay": stats[1],
-            "maxsize": stats[2],
-            "totalrecv": stats[3] or 0,
-            "totalsent": stats[4] or 0,
-            "created": stats[5],
-            "modified": stats[6],
+            "vt": float(stats[0]),
+            "delay": float(stats[1]),
+            "maxsize": int(stats[2]),
+            "totalrecv": int(stats[3] or 0),
+            "totalsent": int(stats[4] or 0),
+            "created": int(stats[5]),
+            "modified": int(stats[6]),
             "msgs": results[1],
             "hiddenmsgs": results[2]
         }
